@@ -55,7 +55,8 @@ def sign(message, ssldir=None, certname=None, **config):
         return message
 
     if ssldir is None or certname is None:
-        raise ValueError("You must set the ssldir and certname keyword arguments.")
+        error = "You must set the ssldir and certname keyword arguments."
+        raise ValueError(error)
 
     certificate = M2Crypto.X509.load_cert(
         "%s/%s.crt" % (ssldir, certname)).as_pem()
@@ -92,6 +93,7 @@ def validate(message, ssldir=None, **config):
 
     if ssldir is None:
         raise ValueError("You must set the ssldir keyword argument.")
+
     def fail(reason):
         log.warn("Failed validation.  %s" % reason)
         return False
